@@ -3,7 +3,7 @@ import os
 import sys
 import logging
 import pandas as pd
-import simulation
+from . import simulation
 
 currentDir = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(currentDir)
